[Bf-blender-cvs] [5cdfceaa1a7] master: Cleanup: use common 'MOD_WELD_MODE_' prefix

Campbell Barton noreply at git.blender.org
Wed Dec 9 05:30:36 CET 2020


Commit: 5cdfceaa1a7efb71d528a04a01cb74181f1aa8e4
Author: Campbell Barton
Date:   Wed Dec 9 14:10:30 2020 +1100
Branches: master
https://developer.blender.org/rB5cdfceaa1a7efb71d528a04a01cb74181f1aa8e4

Cleanup: use common 'MOD_WELD_MODE_' prefix

===================================================================

M	source/blender/makesdna/DNA_modifier_defaults.h
M	source/blender/makesdna/DNA_modifier_types.h
M	source/blender/makesrna/intern/rna_modifier.c
M	source/blender/modifiers/intern/MOD_weld.c

===================================================================

diff --git a/source/blender/makesdna/DNA_modifier_defaults.h b/source/blender/makesdna/DNA_modifier_defaults.h
index 793a229bdc5..e122d50cba8 100644
--- a/source/blender/makesdna/DNA_modifier_defaults.h
+++ b/source/blender/makesdna/DNA_modifier_defaults.h
@@ -801,7 +801,7 @@
 #define _DNA_DEFAULT_WeldModifierData \
   { \
     .merge_dist = 0.001f, \
-    .mode = MOD_WELD_ALL_MODE, \
+    .mode = MOD_WELD_MODE_ALL, \
     .defgrp_name = "", \
   }
 
diff --git a/source/blender/makesdna/DNA_modifier_types.h b/source/blender/makesdna/DNA_modifier_types.h
index d99564ff33e..03cf4aca963 100644
--- a/source/blender/makesdna/DNA_modifier_types.h
+++ b/source/blender/makesdna/DNA_modifier_types.h
@@ -2016,8 +2016,8 @@ enum {
 
 /* #WeldModifierData.mode */
 enum {
-  MOD_WELD_ALL_MODE = 0,
-  MOD_WELD_CONNECTED_MODE = 1,
+  MOD_WELD_MODE_ALL = 0,
+  MOD_WELD_MODE_CONNECTED = 1,
 };
 
 typedef struct DataTransferModifierData {
diff --git a/source/blender/makesrna/intern/rna_modifier.c b/source/blender/makesrna/intern/rna_modifier.c
index 4ce859ddce9..99304d29e00 100644
--- a/source/blender/makesrna/intern/rna_modifier.c
+++ b/source/blender/makesrna/intern/rna_modifier.c
@@ -6232,8 +6232,8 @@ static void rna_def_modifier_weld(BlenderRNA *brna)
   PropertyRNA *prop;
 
   static const EnumPropertyItem mode_items[] = {
-      {MOD_WELD_ALL_MODE, "ALL", 0, "All", "Full merge by distance"},
-      {MOD_WELD_CONNECTED_MODE, "CONNECTED", 0, "Connected", "Only merge along the edges"},
+      {MOD_WELD_MODE_ALL, "ALL", 0, "All", "Full merge by distance"},
+      {MOD_WELD_MODE_CONNECTED, "CONNECTED", 0, "Connected", "Only merge along the edges"},
       {0, NULL, 0, NULL, NULL},
   };
 
diff --git a/source/blender/modifiers/intern/MOD_weld.c b/source/blender/modifiers/intern/MOD_weld.c
index a50323a24ee..e34dcf48c19 100644
--- a/source/blender/modifiers/intern/MOD_weld.c
+++ b/source/blender/modifiers/intern/MOD_weld.c
@@ -1567,7 +1567,7 @@ static bool bvhtree_weld_overlap_cb(void *userdata, int index_a, int index_b, in
 }
 #endif
 
 /** Use for #MOD_WELD_CONNECTED_MODE calculation. */
 struct WeldVertexCluster {
   float co[3];
   uint merged_verts;
@@ -1612,7 +1612,7 @@ static Mesh *weldModifier_doWeld(WeldModifierData *wmd, const ModifierEvalContex
    * This indicates which vert it is or is going to be merged. */
   uint *vert_dest_map = MEM_malloc_arrayN(totvert, sizeof(*vert_dest_map), __func__);
   uint vert_kill_len = 0;
-  if (wmd->mode == MOD_WELD_ALL_MODE)
+  if (wmd->mode == MOD_WELD_MODE_ALL)
 #ifdef USE_BVHTREEKDOP
   {
     /* Get overlap map. */
@@ -1709,7 +1709,7 @@ static Mesh *weldModifier_doWeld(WeldModifierData *wmd, const ModifierEvalContex
   }
 #endif
   else {
-    BLI_assert(wmd->mode == MOD_WELD_CONNECTED_MODE);
+    BLI_assert(wmd->mode == MOD_WELD_MODE_CONNECTED);
 
     MEdge *medge, *me;
@@ -1567,7 +1567,7 @@ static bool bvhtree_weld_overlap_cb(void *userdata, int index_a, int index_b, in
 #endif
 
-/** Use for #MOD_WELD_CONNECTED_MODE calculation. */
+/** Use for #MOD_WELD_MODE_CONNECTED calculation. */
 struct WeldVertexCluster {
   float co[3];



More information about the Bf-blender-cvs mailing list